@@ -10,8 +10,13 @@ from log_labeler import local, LOG_LABEL_REQUEST_SETTING, DEFAULT_HEADER_VALUE,
 
 logger = logging.getLogger(__name__)
 
+try:
+    from django.utils.deprecation import MiddlewareMixin
+except ImportError:
+    MiddlewareMixin = object
 
-class HeaderToLabelMiddleware(object):
+
+class HeaderToLabelMiddleware(MiddlewareMixin):
     """
     Provides full logging of requests and responses
     """
